// java wrapper for vtkReebGraphSimplificationFilter object
//

package vtk;
import vtk.*;

public class vtkReebGraphSimplificationFilter extends vtkDirectedGraphAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native void SetSimplificationThreshold_2(double id0);
  public void SetSimplificationThreshold(double id0)
    { SetSimplificationThreshold_2(id0); }

  private native double GetSimplificationThreshold_3();
  public double GetSimplificationThreshold()
    { return GetSimplificationThreshold_3(); }

  private native void SetSimplificationMetric_4(vtkReebGraphSimplificationMetric id0);
  public void SetSimplificationMetric(vtkReebGraphSimplificationMetric id0)
    { SetSimplificationMetric_4(id0); }

  private native long GetOutput_5();
  public vtkReebGraph GetOutput() {
    long temp = GetOutput_5();

    if (temp == 0) return null;
    return (vtkReebGraph)vtkObjectBase.JAVA_OBJECT_MANAGER.getJavaObject(temp);
}

  public vtkReebGraphSimplificationFilter() { super(); }

  public vtkReebGraphSimplificationFilter(long id) { super(id); }
  public native long   VTKInit();

}
